# Sauce Labs Visual for Python

Sauce Labs Visual for Python exposes Sauce Labs Visual Testing for your Python project with Selenium.

## Installation & Usage

View installation and usage instructions on the [Sauce Docs website](https://docs.saucelabs.com/visual-testing/integrations/python/).

## Building

`pip` is required to be able to build the Sauce Visual Python SDK. You can install the requirements for development using:

```sh
pip install -r requirements/dev.txt
```

After the requirements are installed, run the following command to build the Sauce Visual Python SDK:

```sh
python -m build
```

## Running the tests

```sh
python -m pytest
```
